@@ -72,7 +72,7 @@ def estimate_investment_net_worth(results):
         for k, v in results["sections"]["Liabilities"]["rows"].items():
             if (
                 v["Value Code"]["text"] != ""
-                and v["Value Code"]["text"] != "•"
+                and v["Value Code"]["text"] != "-1"
             ):
                 liabilities_total.append(key_codes[v["Value Code"]["text"]])
 
@@ -86,7 +86,7 @@ def estimate_investment_net_worth(results):
         for k, v in results["sections"]["Non-Investment Income"][
             "rows"
         ].items():
-            if v["Income"]["text"] != "" and v["Income"]["text"] != "•":
+            if v["Income"]["text"] != "" and v["Income"]["text"] != "-1":
                 salary = v["Income"]["text"].replace(",", "").strip("$")
                 if not re.match(r"^-?\d+(?:\.\d+)?$", salary) is None:
                     salaries.append(float(salary))
